Learn R Programming

PhyInsight (version 0.1.0)

genPhytree: Create a Phylogenetic Tree Object

Description

Create a phylo tree object using a manipulated DNA string set object.

Usage

genPhytree(manipulated_stringset, incompleteDist = TRUE)

Value

A phylogenetic tree object

Arguments

manipulated_stringset

A manipulated string set object.

incompleteDist

A logical value to state whether to create a tree from incomplete distances.

Examples

Run this code
# create and plot a phylo tree
specdf_Anth <- querySpecData("Antheraea polyphemus")[1:10,]

DNABin_Anth <- genDNABin(specdf_Anth)

DNAStringset_Anth <- genDNAStringSet(DNABin_Anth)

DNAStringSet_Anth_manipulated <- ManipStringSet(DNAStringset_Anth)

Phytree_Anth <- genPhytree(DNAStringSet_Anth_manipulated)

Phytree_Anth$edge.length <- Phytree_Anth$edge.length + (mean(Phytree_Anth$edge.length) * 0.1)

plot(Phytree_Anth)

Run the code above in your browser using DataLab